#!/bin/env python

# -*- coding: utf-8 -*-

from __future__ import unicode_literals
import os
import sys
import sqlite3


class Cursor(object):
    def __init__(self, connection):
        self.connection = connection

    def __enter__(self):
        self.cursor = self.connection.cursor()
        return self.cursor

    def __exit__(self, type, value, traceback):
        self.cursor.close()
    
class DatabaseConnector(object):

    def __enter__(self):
        path = os.path.dirname(os.path.abspath((__file__)))
        self.db_path = os.path.join(path, "icd10.db")
        self.connection = sqlite3.connect(self.db_path)
        return self

    def __exit__(self, type, value, traceback):
        self.connection.close()
        
    def search(self, search):
        search = " {0} ".format(search)
        search = search.replace(" ", "%")
        sql = """
            select Code, Titel
            from Codes
            where Titel like ?
        """
        with Cursor(self.connection) as cursor:
            return cursor.execute(sql, (search, )*1).fetchall()
        
if __name__ == "__main__":
    running = True
    while running:
        searchterm = input("\nSuchbegriff: ") 
        if searchterm == "exit":
            running = False
        else:
            with DatabaseConnector() as database:
                results = database.search(searchterm)
           
            header = "\nCode\t| Text"
            line = "-" * 14
            print(header)
            print(line)
            for code in results:
                tabline = "{0}\t| {1}".format(code[0],code[1])
                print(tabline)